OC.L10N.register(
    "mail",
    {
    "Mail" : "Pošta",
    "Name" : "naziv",
    "Password" : "Password",
    "None" : "Ništa",
    "Save" : "Save",
    "Connect" : "Poveži se",
    "Select account" : "Označite nalog",
    "Send" : "Pošalji",
    "Select" : "Obeleži",
    "Delete" : "Delete",
    "Favorites" : "Omiljene",
    "Other" : "Ostali",
    "Attachments" : "Prilozi",
    "Settings" : "Postavke",
    "Add folder" : "Add folder",
    "Remove account" : "Ukloni nalog",
    "Cancel" : "Otkaži",
    "Mark all as read" : "Označi sve kao pročitano",
    "Clear cache" : "Očisti keš",
    "Reply" : "Odgovori",
    "Forward" : "Prosledi",
    "General" : "Opšte",
    "User" : "User",
    "Search" : "Search",
    "Refresh" : "Osveži"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
